@@ -11,9 +11,9 @@ from pathlib import Path
 import torch
 import tyro
 
-from nerfstudio.configs import base as cfg
-from nerfstudio.data.base import AnnotatedDataParserUnion
-from nerfstudio.data.datasets import InputDataset
+from nerfstudio.configs import model_configs as cfg
+from nerfstudio.data.datamanagers import AnnotatedDataParserUnion
+from nerfstudio.data.utils.datasets import InputDataset
 from nerfstudio.viewer.server import viewer_utils
 
 logging.basicConfig(format="[%(filename)s:%(lineno)d] %(message)s", level=logging.INFO)
@@ -30,9 +30,12 @@ def main(
     log_base_dir: Path = Path("/tmp/nerfstudio_viewer_logs"),
 ) -> None:
     """Main function."""
-    viewer_state = viewer_utils.ViewerState(config.viewer)
-    datamanager = config.pipeline.datamanager.setup()
-    viewer_state.init_scene(dataset=datamanager.train_input_dataset, start_train=False)
+    viewer_state = viewer_utils.ViewerState(
+        viewer,
+        log_filename=log_base_dir / viewer.relative_log_filename,
+    )
+    dataset = InputDataset(dataparser.setup().get_dataset_inputs(split="train"))
+    viewer_state.init_scene(dataset=dataset, start_train=False)
     logging.info("Please refresh and load page at: %s", viewer_state.viewer_url)
     time.sleep(30)  # allowing time to refresh page
 
